==> jc-1.4.0.tar.gz: java/nio/InvalidMarkException.h <==
// public class java.nio.InvalidMarkException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class b7e704701c278e65 java_lang_IllegalStateException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 4f84a9b58f0f119b java_nio_InvalidMarkException

// header file dependencies
// @dep_header java_lang_IllegalStateException

#include "java/lang/IllegalStateException.h"

#ifndef _JC_java_nio_InvalidMarkException_H_
#define _JC_java_nio_InvalidMarkException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_InvalidMarkException$sub_refs	_jc_java_nio_InvalidMarkException$sub_refs;
typedef struct _jc_java_nio_InvalidMarkException$sub_nonrefs	_jc_java_nio_InvalidMarkException$sub_nonrefs;
typedef struct _jc_java_nio_InvalidMarkException$refs	_jc_java_nio_InvalidMarkException$refs;
typedef struct _jc_java_nio_InvalidMarkException$nonrefs	_jc_java_nio_InvalidMarkException$nonrefs;
typedef struct _jc_java_nio_InvalidMarkException$object	_jc_java_nio_InvalidMarkException$object;

typedef const struct _jc_java_nio_InvalidMarkException$vmethods	_jc_java_nio_InvalidMarkException$vmethods;
typedef const struct _jc_java_nio_InvalidMarkException$vtable	_jc_java_nio_InvalidMarkException$vtable;
typedef const struct _jc_java_nio_InvalidMarkException$vtype	_jc_java_nio_InvalidMarkException$vtype;

// Constructors
extern void _jc_java_nio_InvalidMarkException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_InvalidMarkException$object *);

// Virtual methods structure
struct _jc_java_nio_InvalidMarkException$vmethods {
};

// Vtable
struct _jc_java_nio_InvalidMarkException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalStateException$vmethods	java_lang_IllegalStateException;
	_jc_java_nio_InvalidMarkException$vmethods	java_nio_InvalidMarkException;
};

// Vtype
struct _jc_java_nio_InvalidMarkException$vtype {
	_jc_type			type;
	_jc_java_nio_InvalidMarkException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_InvalidMarkException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_InvalidMarkException$refs {
    _jc_java_nio_InvalidMarkException$sub_refs	java_nio_InvalidMarkException;
    _jc_java_lang_IllegalStateException$sub_refs	java_lang_IllegalStateException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_InvalidMarkException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_InvalidMarkException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalStateException$sub_nonrefs	java_lang_IllegalStateException;
    _jc_java_nio_InvalidMarkException$sub_nonrefs	java_nio_InvalidMarkException;
};

// Object instance structure
struct _jc_java_nio_InvalidMarkException$object {
	_jc_java_nio_InvalidMarkException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_InvalidMarkException$vtype	*vtype;
	_jc_java_nio_InvalidMarkException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_InvalidMarkException$vtype _jc_java_nio_InvalidMarkException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_InvalidMarkException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_InvalidMarkException$class_object;

#endif	/* _JC_java_nio_InvalidMarkException_H_ */

==> jc-1.4.6.tar.gz: java/nio/InvalidMarkException.h <==
// public class java.nio.InvalidMarkException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class b7e704701c278e65 java_lang_IllegalStateException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 4f84a9b58f0f119b java_nio_InvalidMarkException

// header file dependencies
// @dep_header java_lang_IllegalStateException

#include "java/lang/IllegalStateException.h"

#ifndef _JC_java_nio_InvalidMarkException_H_
#define _JC_java_nio_InvalidMarkException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_InvalidMarkException$sub_refs	_jc_java_nio_InvalidMarkException$sub_refs;
typedef struct _jc_java_nio_InvalidMarkException$sub_nonrefs	_jc_java_nio_InvalidMarkException$sub_nonrefs;
typedef struct _jc_java_nio_InvalidMarkException$refs	_jc_java_nio_InvalidMarkException$refs;
typedef struct _jc_java_nio_InvalidMarkException$nonrefs	_jc_java_nio_InvalidMarkException$nonrefs;
typedef struct _jc_java_nio_InvalidMarkException$object	_jc_java_nio_InvalidMarkException$object;

typedef const struct _jc_java_nio_InvalidMarkException$vmethods	_jc_java_nio_InvalidMarkException$vmethods;
typedef const struct _jc_java_nio_InvalidMarkException$vtable	_jc_java_nio_InvalidMarkException$vtable;
typedef const struct _jc_java_nio_InvalidMarkException$vtype	_jc_java_nio_InvalidMarkException$vtype;

// Constructors
extern void _jc_java_nio_InvalidMarkException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_InvalidMarkException$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_nio_InvalidMarkException$vmethods {
};

// Vtable
struct _jc_java_nio_InvalidMarkException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalStateException$vmethods	java_lang_IllegalStateException;
	_jc_java_nio_InvalidMarkException$vmethods	java_nio_InvalidMarkException;
};

// Vtype
struct _jc_java_nio_InvalidMarkException$vtype {
	_jc_type			type;
	_jc_java_nio_InvalidMarkException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_InvalidMarkException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_InvalidMarkException$refs {
    _jc_java_nio_InvalidMarkException$sub_refs	java_nio_InvalidMarkException;
    _jc_java_lang_IllegalStateException$sub_refs	java_lang_IllegalStateException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_InvalidMarkException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_InvalidMarkException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalStateException$sub_nonrefs	java_lang_IllegalStateException;
    _jc_java_nio_InvalidMarkException$sub_nonrefs	java_nio_InvalidMarkException;
};

// Object instance structure
struct _jc_java_nio_InvalidMarkException$object {
	_jc_java_nio_InvalidMarkException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_InvalidMarkException$vtype	*vtype;
	_jc_java_nio_InvalidMarkException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_InvalidMarkException$vtype _jc_java_nio_InvalidMarkException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_InvalidMarkException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_InvalidMarkException$class_object;

#endif	/* _JC_java_nio_InvalidMarkException_H_ */
